@@ -426,7 +426,10 @@ class Apartment(Entity, Mapping):
         apartment.floor_number = floor_number
         apartment.number = number
         for attr_name, value in attribs.iteritems():
-            setattr(apartment, attr_name, value)
+            try:
+                setattr(apartment, attr_name, value)
+            except AttributeError:
+                pass
         return apartment
 
     def area_coords(self, floor_dir=None, size=None, reverse=False,
